<?php

namespace AdRepository\Devdetail\Http\Controllers;

use App\Http\Controllers\AdminApiController as AdminController;
use AdRepository\Devdetail\Http\Requests\DevdetailAdminApiRequest;
use AdRepository\Devdetail\Interfaces\DevdetailRepositoryInterface;
use AdRepository\Devdetail\Models\Devdetail;

/**
 * Admin API controller class.
 */
class DevdetailAdminApiController extends AdminController
{
    /**
     * Initialize devdetail controller.
     *
     * @param type DevdetailRepositoryInterface $devdetail
     *
     * @return type
     */
    public function __construct(DevdetailRepositoryInterface $devdetail)
    {
        $this->repository = $devdetail;
        parent::__construct();
    }

    /**
     * Display a list of devdetail.
     *
     * @return json
     */
    public function index(DevdetailAdminApiRequest $request)
    {
        $devdetails  = $this->repository
            ->setPresenter('\\AdRepository\\Devdetail\\Repositories\\Presenter\\DevdetailListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $devdetails['code'] = 2000;
        return response()->json($devdetails) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display devdetail.
     *
     * @param Request $request
     * @param Model   Devdetail
     *
     * @return Json
     */
    public function show(DevdetailAdminApiRequest $request, Devdetail $devdetail)
    {
        $devdetail         = $devdetail->presenter();
        $devdetail['code'] = 2001;
        return response()->json($devdetail)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new devdetail.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(DevdetailAdminApiRequest $request, Devdetail $devdetail)
    {
        $devdetail         = $devdetail->presenter();
        $devdetail['code'] = 2002;
        return response()->json($devdetail)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new devdetail.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(DevdetailAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $devdetail          = $this->repository->create($attributes);
            $devdetail          = $devdetail->presenter();
            $devdetail['code']  = 2004;

            return response()->json($devdetail)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show devdetail for editing.
     *
     * @param Request $request
     * @param Model   $devdetail
     *
     * @return json
     */
    public function edit(DevdetailAdminApiRequest $request, Devdetail $devdetail)
    {
        $devdetail         = $devdetail->presenter();
        $devdetail['code'] = 2003;
        return response()-> json($devdetail)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the devdetail.
     *
     * @param Request $request
     * @param Model   $devdetail
     *
     * @return json
     */
    public function update(DevdetailAdminApiRequest $request, Devdetail $devdetail)
    {
        try {

            $attributes = $request->all();

            $devdetail->update($attributes);
            $devdetail         = $devdetail->presenter();
            $devdetail['code'] = 2005;

            return response()->json($devdetail)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the devdetail.
     *
     * @param Request $request
     * @param Model   $devdetail
     *
     * @return json
     */
    public function destroy(DevdetailAdminApiRequest $request, Devdetail $devdetail)
    {

        try {

            $t = $devdetail->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('devdetail::devdetail.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
