<?php

namespace AdRepository\Devdetail\Http\Controllers;

use App\Http\Controllers\PublicApiController as PublicController;
use AdRepository\Devdetail\Interfaces\DevdetailRepositoryInterface;
use AdRepository\Devdetail\Repositories\Presenter\DevdetailItemTransformer;

/**
 * Pubic API controller class.
 */
class DevdetailPublicApiController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \AdRepository\Devdetail\Interfaces\DevdetailRepositoryInterface $devdetail
     *
     * @return type
     */
    public function __construct(DevdetailRepositoryInterface $devdetail)
    {
        $this->repository = $devdetail;
        parent::__construct();
    }

    /**
     * Show devdetail's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $devdetails = $this->repository
            ->setPresenter('\\AdRepository\\Devdetail\\Repositories\\Presenter\\DevdetailListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $devdetails['code'] = 2000;
        return response()->json($devdetails)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show devdetail.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $devdetail = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($devdetail)) {
            $devdetail         = $this->itemPresenter($module, new DevdetailItemTransformer);
            $devdetail['code'] = 2001;
            return response()->json($devdetail)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
