<?php

namespace AdRepository\Devdetail\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use AdRepository\Devdetail\Models\Devdetail;

class DevdetailPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the devdetail.
     *
     * @param User $user
     * @param Devdetail $devdetail
     *
     * @return bool
     */
    public function view(User $user, Devdetail $devdetail)
    {
        if ($user->canDo('devdetail.devdetail.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $devdetail->user_id;
    }

    /**
     * Determine if the given user can create a devdetail.
     *
     * @param User $user
     * @param Devdetail $devdetail
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('devdetail.devdetail.create');
    }

    /**
     * Determine if the given user can update the given devdetail.
     *
     * @param User $user
     * @param Devdetail $devdetail
     *
     * @return bool
     */
    public function update(User $user, Devdetail $devdetail)
    {
        if ($user->canDo('devdetail.devdetail.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $devdetail->user_id;
    }

    /**
     * Determine if the given user can delete the given devdetail.
     *
     * @param User $user
     * @param Devdetail $devdetail
     *
     * @return bool
     */
    public function destroy(User $user, Devdetail $devdetail)
    {
        if ($user->canDo('devdetail.devdetail.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $devdetail->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
