<?php

namespace AdRepository\Devdetail\Providers;

use Illuminate\Support\ServiceProvider;

class DevdetailServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'devdetail');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'devdetail');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('devdetail', function ($app) {
            return $this->app->make('AdRepository\Devdetail\Devdetail');
        });

        // Bind Devdetail to repository
        $this->app->bind(
            \AdRepository\Devdetail\Interfaces\DevdetailRepositoryInterface::class,
            \AdRepository\Devdetail\Repositories\Eloquent\DevdetailRepository::class
        );

        $this->app->register(\AdRepository\Devdetail\Providers\AuthServiceProvider::class);
        $this->app->register(\AdRepository\Devdetail\Providers\EventServiceProvider::class);
        $this->app->register(\AdRepository\Devdetail\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['devdetail'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/devdetail.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/devdetail')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/devdetail')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
